==> drop_account-2.3.1.tar.gz: drop_account/l10n/ru.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) удалил(а) свой аккаунт",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) удалил(а) свой аккаунт",
    "%1$s deleted their account" : "%1$s удалил(а) свой аккаунт",
    "An user <strong>deleted</strong> its account" : "Пользователь <strong>удалил(а)</strong> свой аккаунт",
    "User-Session unexpectedly expired" : "Пользовательская сессия неожиданно истекла",
    "Successfully sent email" : "Письмо отправлено успешно",
    "You have no email set up into your account" : "В вашем аккаунте не настроена электронная почта",
    "Unexpected error sending email. Please contact your administrator." : "Непредвиденная ошибка отправки email. Пожалуйста, свяжитесь с вашим администратором.",
    "Confirm your account deletion on %s" : "Подтвердите удаление учетной записи на %s",
    "Account deletion confirmation for %s" : "Подтверждение удаления учетной записи на %s",
    "Hello," : "Привет,",
    "Someone - probably you - asked to delete their account on %s." : "Кто-то — возможно, вы — запросил удаление своей учетной записи на %s.",
    "To confirm the account deletion, you may click on the button below." : "Чтобы подтвердить удаление учетной записи, вы можете нажать на кнопку ниже.",
    "Delete account" : "Удалить аккаунт",
    "Cheers!" : "Ура!",
    "User account deletion" : "Удаление пользовательского аккаунта",
    "An app to allow users to delete their accounts." : "Приложение для удаления учетных записей.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Описание\n\nЭто приложение позволяет пользователям удалять свои учетные записи, стирая все свои данные.\n\nОно также может отправлять администраторам уведомления об удалении учетных записей.",
    "Account deletion" : "Удаление аккаунта",
    "Allows users to delete themselves their own account." : "Позволяет пользователям самостоятельно удалять свою учетную запись.",
    "Email confirmation" : "Подтверждение по email",
    "Require confirmation by email" : "Запросить подтверждение по email",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Потребует от пользователей кликнуть ссылку подтверждения, отправленную по email, чтобы подтвердить свое действие.",
    "Data purge" : "Очистка данных",
    "Users are not removed right away but disabled until a background job removed their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Пользователи не удаляются сразу, а отключаются до тех пор, пока фоновое задание не удалит их данные навсегда. В это время администраторы могут «спасти» пользователей, повторно активировав их аккаунт.",
    "Purge user data as soon as possible." : "Очистить пользовательские данные как можно скорее.",
    "Uses the next background job available to completely remove the user's data." : "Использовать следующее доступное фоновое задание для полного удаления данных пользователя.",
    "Purge user data after a while." : "Очистить пользовательские данные через некоторое время.",
    "Deletes user data after a grace period." : "Удаляет данные пользователя по истечении льготного периода.",
    "Grace period duration" : "Длительность льготного периода",
    "One day" : "Один день",
    "One week" : "Одна неделя",
    "One month" : "Один месяц",
    "Error while changing require confirmation setting" : "Ошибка при изменении настройки подтверждения",
    "Error while changing delay purge setting" : "Ошибка при изменении настройки задержки очистки",
    "Error while changing delay purge hours setting" : "Ошибка при изменении настройки часов задержки очистки",
    "Delete my account" : "Удалить мой аккаунт",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Удаление вашей учетной записи приведет к удалению всех ваших файлов и данных из используемых вами приложений, таких как календарь и контакты.",
    "Account marked for deletion" : "Аккаунт помечен для удаления",
    "Your account has been disabled and the data will be removed shortly." : "Ваша учетная запись была отключена, данные будут удалены в ближайшее время.",
    "You are going to be redirected to the login page in a few seconds…" : "Через несколько секунд вы будете перенаправлены на страницу входа…",
    "Email confirmation required" : "Требуется подтверждение по email",
    "Please click the link into the email we've just sent you to finish deleting your account." : "Нажмите на ссылку в email, который мы только что отправили вам, чтобы завершить удаление вашей учетной записи.",
    "This action is irreversible!" : "Это действие необратимо!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "После подтверждения удаления вашей учетной записи вы будете перенаправлены на страницу входа.",
    "You are the only user of this instance, you can't delete your account." : "Вы единственный пользователь этого сервера, вы не можете удалить свою учетную запись.",
    "You are the only admin of this instance, you can't delete your account." : "Вы единственный администратор этого сервера, вы не можете удалить свою учетную запись.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Администратор требует подтверждения по email для удаления вашей учетной записи. Сначала заполните свой адрес электронной почты в личных настройках.",
    "Do you really wish to delete your account?" : "Вы действительно хотите удалить свой аккаунт?",
    "We will send you an email to confirm this action." : "Мы отправим вам email для подтверждения этого действия.",
    "Check this to confirm the deletion request" : "Установите флажок, чтобы подтвердить запрос на удаление",
    "Deleting your data…" : "Удаление данных…",
    "Error while deleting the account" : "Ошибка при удалении учетной записи",
    "Your account has been marked for deletion. You can now close this window." : "Ваша учетная запись была помечена для удаления. Теперь вы можете закрыть это окно.",
    "Account not found." : "Аккаунт не найден.",
    "The token provided was not found." : "Предоставленный токен не найден.",
    "Unknown error." : "Неизвестная ошибка."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> drop_account-2.4.0.tar.gz: drop_account/l10n/ru.js <==
OC.L10N.register(
    "drop_account",
    {
    "%1$s (%2$s - %3$s) deleted their account" : "%1$s (%2$s - %3$s) удалил(а) свой аккаунт",
    "%1$s (%2$s) deleted their account" : "%1$s (%2$s) удалил(а) свой аккаунт",
    "%1$s deleted their account" : "%1$s удалил(а) свой аккаунт",
    "%1$s requested to delete their account. It has been disabled and will automatically be removed on %2$s" : "Ваша учетная запись была отключена, данные будут удалены в ближайшее время.",
    "A user <strong>deleted</strong> its account" : "Пользователь <strong>удалил(а)</strong> свой аккаунт",
    "User session not found" : "Аккаунт не найден.",
    "User-Session unexpectedly expired" : "Пользовательская сессия неожиданно истекла",
    "Successfully sent email" : "Письмо отправлено успешно",
    "You have no email set up into your account" : "В вашем аккаунте не настроена электронная почта",
    "Unexpected error sending email. Please contact your administrator." : "Непредвиденная ошибка отправки email. Пожалуйста, свяжитесь с вашим администратором.",
    "Confirm your account deletion on %s" : "Подтвердите удаление учетной записи на %s",
    "Account deletion confirmation for %s" : "Подтверждение удаления учетной записи на %s",
    "Hello," : "Привет,",
    "Someone - probably you - asked to delete their account on %s." : "Кто-то — возможно, вы — запросил удаление своей учетной записи на %s.",
    "To confirm the account deletion, you may click on the button below." : "Чтобы подтвердить удаление учетной записи, вы можете нажать на кнопку ниже.",
    "Delete account" : "Удалить аккаунт",
    "Cheers!" : "Ура!",
    "You are the only user on the server, you can't delete your account." : "Вы единственный пользователь этого сервера, вы не можете удалить свою учетную запись.",
    "You are the only admin on the server, you can't delete your account." : "Вы единственный администратор этого сервера, вы не можете удалить свою учетную запись.",
    "Account deletion on %s scheduled" : "Удаление аккаунта",
    "Account on %s deleted" : "Удаление аккаунта",
    "User account deletion" : "Удаление пользовательского аккаунта",
    "An app to allow users to delete their accounts." : "Приложение для удаления учетных записей.",
    "# Description\n\nThis app allows users to delete their accounts by removing all their data.\n\nIt can also send activities to the admins about deleted accounts." : "# Описание\n\nЭто приложение позволяет пользователям удалять свои учетные записи, стирая все свои данные.\n\nОно также может отправлять администраторам уведомления об удалении учетных записей.",
    "Account deletion" : "Удаление аккаунта",
    "Allows users to delete themselves their own account." : "Позволяет пользователям самостоятельно удалять свою учетную запись.",
    "Email confirmation" : "Подтверждение по email",
    "Require confirmation by email" : "Запросить подтверждение по email",
    "Will require users to click a confirmation link sent by email to confirm their action." : "Потребует от пользователей кликнуть ссылку подтверждения, отправленную по email, чтобы подтвердить свое действие.",
    "Data purge" : "Очистка данных",
    "Users are not removed right away but disabled until a background job removes their data for good. In the meanwhile, admins can \"save\" users by enabling them back." : "Пользователи не удаляются сразу, а отключаются до тех пор, пока фоновое задание не удалит их данные навсегда. В это время администраторы могут «спасти» пользователей, повторно активировав их аккаунт.",
    "Purge user data as soon as possible." : "Очистить пользовательские данные как можно скорее.",
    "Uses the next background job available to completely remove the user's data." : "Использовать следующее доступное фоновое задание для полного удаления данных пользователя.",
    "Purge user data after a while." : "Очистить пользовательские данные через некоторое время.",
    "Deletes user data after a grace period." : "Удаляет данные пользователя по истечении льготного периода.",
    "Grace period duration" : "Длительность льготного периода",
    "One day" : "Один день",
    "One week" : "Одна неделя",
    "One month" : "Один месяц",
    "Error while changing require confirmation setting" : "Ошибка при изменении настройки подтверждения",
    "Error while changing delay purge setting" : "Ошибка при изменении настройки задержки очистки",
    "Error while changing delay purge hours setting" : "Ошибка при изменении настройки часов задержки очистки",
    "Delete my account" : "Удалить мой аккаунт",
    "Deleting your account will delete all your files and data from the apps you use, such as calendar and contacts." : "Удаление вашей учетной записи приведет к удалению всех ваших файлов и данных из используемых вами приложений, таких как календарь и контакты.",
    "Account marked for deletion" : "Аккаунт помечен для удаления",
    "Your account has been disabled and the data will be removed shortly." : "Ваша учетная запись была отключена, данные будут удалены в ближайшее время.",
    "You are going to be redirected to the login page in a few seconds…" : "Через несколько секунд вы будете перенаправлены на страницу входа…",
    "Email confirmation required" : "Требуется подтверждение по email",
    "Please click the link into the email we've just sent you to finish deleting your account." : "Нажмите на ссылку в email, который мы только что отправили вам, чтобы завершить удаление вашей учетной записи.",
    "This action is irreversible!" : "Это действие необратимо!",
    "After confirming the deletion of your account, you will be redirected to the login page." : "После подтверждения удаления вашей учетной записи вы будете перенаправлены на страницу входа.",
    "You are the only user of this instance, you can't delete your account." : "Вы единственный пользователь этого сервера, вы не можете удалить свою учетную запись.",
    "You are the only admin of this instance, you can't delete your account." : "Вы единственный администратор этого сервера, вы не можете удалить свою учетную запись.",
    "An email confirmation is required by your admin to delete your account. Please fill your email in your personal settings first." : "Администратор требует подтверждения по email для удаления вашей учетной записи. Сначала заполните свой адрес электронной почты в личных настройках.",
    "Do you really wish to delete your account?" : "Вы действительно хотите удалить свой аккаунт?",
    "We will send you an email to confirm this action." : "Мы отправим вам email для подтверждения этого действия.",
    "Check this to confirm the deletion request" : "Установите флажок, чтобы подтвердить запрос на удаление",
    "Error while deleting the account" : "Ошибка при удалении учетной записи",
    "Your account has been marked for deletion. You can now close this window." : "Ваша учетная запись была помечена для удаления. Теперь вы можете закрыть это окно.",
    "Account not found." : "Аккаунт не найден.",
    "The token provided was not found." : "Предоставленный токен не найден.",
    "Unknown error." : "Неизвестная ошибка."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
